=========
Changelog
=========

Version 0.1
===========

- Add Portfolio class for managing your stock portfolio
- Test Portfolio
- Add visualization helpers, e.g. plot_price

Version 0.0.6
=============

- Refactor the base class StockBase to Ticker.
- Fixed README still showing the outdated tutorial.

Version 0.0.5
=============

- get_stock_info() is not get_price().
- add properties: institutional_holders, major_holders, mutual_fund_holders, sustainability, company_information
- add get_cashflow(), get_earnings(), get_balancesheet()

Version 0.0.3
=============

- pytest
- tox
- travisCI
- Readme
- First publish to PyPi


Version 0.0.1
=============

- Initial commit
